@@ -57,6 +57,7 @@ static const char * const gtkui_defaults[] = {
     "autoscroll", "TRUE",
     "playlist_columns", "title artist album queued length",
     "playlist_headers", "TRUE",
+    "playlist_headers_sortable", "TRUE",
     "show_remaining_time", "FALSE",
 
 #ifdef USE_GTK3
@@ -377,14 +378,48 @@ static gboolean ui_volume_value_changed_cb (GtkButton *, double volume)
     return true;
 }
 
-static void ui_volume_pressed_cb (GtkButton *)
+static gboolean ui_volume_button_press_cb (GtkWidget *, GdkEvent * event)
 {
-    volume_slider_is_moving = true;
+    static int old_volume = 0;
+    GdkEventButton * button_event = (GdkEventButton *) event;
+
+    /* ignore double and triple clicks */
+    if (button_event->type != GDK_BUTTON_PRESS)
+        return false;
+
+    /* handle left mouse button */
+    if (button_event->button == 1)
+    {
+        volume_slider_is_moving = true;
+        return false;
+    }
+
+    /* (un)mute with middle mouse button */
+    if (button_event->button == 2)
+    {
+        int current_volume = aud_drct_get_volume_main ();
+        if (current_volume)
+        {
+            old_volume = current_volume;
+            aud_drct_set_volume_main (0);
+        }
+        else
+            aud_drct_set_volume_main (old_volume);
+
+        return true;
+    }
+
+    return false;
 }
 
-static void ui_volume_released_cb (GtkButton *)
+static gboolean ui_volume_button_release_cb (GtkWidget *, GdkEvent * event)
 {
-    volume_slider_is_moving = false;
+    GdkEventButton * button_event = (GdkEventButton *) event;
+
+    if (button_event->button == 1)
+        volume_slider_is_moving = false;
+
+    return false;
 }
 
 static void ui_volume_slider_update (void * button)
@@ -428,6 +463,14 @@ static void update_volume_delta ()
     gtk_adjustment_set_page_increment (adjustment, volume_delta);
 }
 
+static void set_menu_button_icon (GtkToolButton * button)
+{
+    if (aud_get_bool ("gtkui", "symbolic_icons"))
+        gtk_tool_button_set_icon_name (button, "open-menu-symbolic");
+    else
+        gtk_tool_button_set_icon_name (button, "audacious");
+}
+
 static void set_button_icon (GtkToolButton * button, const char * icon)
 {
     if (aud_get_bool ("gtkui", "symbolic_icons"))
@@ -798,6 +841,7 @@ bool GtkUI::init ()
     pw_col_init ();
 
     window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+    gtk_window_set_role ((GtkWindow *) window, "mainwindow");
 
     accel = gtk_accel_group_new ();
     gtk_window_add_accel_group ((GtkWindow *) window, accel);
@@ -888,7 +932,12 @@ bool GtkUI::init ()
 
     volume = gtk_volume_button_new ();
     GtkIconSize icon_size = gtk_tool_shell_get_icon_size ((GtkToolShell *) toolbar);
+#ifdef USE_GTK3
+    g_object_set ((GObject *) volume, "size", icon_size,
+     "use-symbolic", aud_get_bool ("gtkui", "symbolic_icons"), nullptr);
+#else
     g_object_set ((GObject *) volume, "size", icon_size, nullptr);
+#endif
     gtk_button_set_relief ((GtkButton *) volume, GTK_RELIEF_NONE);
     int delta = aud_get_int ("volume_delta");
     gtk_scale_button_set_adjustment ((GtkScaleButton *) volume,
@@ -926,12 +975,11 @@ bool GtkUI::init ()
     g_signal_connect (slider, "button-release-event", (GCallback) ui_slider_button_release_cb, nullptr);
 
     volume_change_handler_id = g_signal_connect (volume, "value-changed", (GCallback) ui_volume_value_changed_cb, nullptr);
-    g_signal_connect (volume, "pressed", (GCallback) ui_volume_pressed_cb, nullptr);
-    g_signal_connect (volume, "released", (GCallback) ui_volume_released_cb, nullptr);
+    g_signal_connect (volume, "button-press-event", (GCallback) ui_volume_button_press_cb, nullptr);
+    g_signal_connect (volume, "button-release-event", (GCallback) ui_volume_button_release_cb, nullptr);
 
     timer_add (TimerRate::Hz4, ui_volume_slider_update, volume);
 
-    g_signal_connect (window, "map-event", (GCallback) pl_notebook_grab_focus, nullptr);
     g_signal_connect (window, "delete-event", (GCallback) window_delete, nullptr);
     g_signal_connect (window, "window-state-event", (GCallback) window_state_cb, nullptr);
     g_signal_connect (window, "key-press-event", (GCallback) window_keypress_cb, nullptr);
@@ -983,6 +1031,11 @@ void GtkUI::cleanup ()
     audgui_cleanup ();
 }
 
+GtkWindow * get_main_window ()
+{
+    return (GtkWindow *) window;
+}
+
 #ifndef USE_GTK3
 static void menu_position_cb (GtkMenu *, int * x, int * y, int * push, void * button)
 {
@@ -1057,7 +1110,7 @@ void show_hide_menu ()
         if (! menu_button)
         {
             menu_button = gtk_toggle_tool_button_new ();
-            gtk_tool_button_set_icon_name ((GtkToolButton *) menu_button, "audacious");
+            set_menu_button_icon ((GtkToolButton *) menu_button);
             gtk_tool_item_set_tooltip_text (menu_button, _("Menu"));
             g_signal_connect (menu_button, "destroy", (GCallback)
              gtk_widget_destroyed, & menu_button);
@@ -1127,7 +1180,7 @@ static void popup_menu (GtkMenu * menu, const GdkEvent * event)
     gtk_menu_popup_at_pointer (menu, event);
 #else
     GdkEventButton * button_event = (GdkEventButton *) event;
-    gtk_menu_popup ((GtkMenu *) menu, nullptr, nullptr, nullptr, nullptr,
+    gtk_menu_popup (menu, nullptr, nullptr, nullptr, nullptr,
      button_event->button, button_event->time);
 #endif
 }
@@ -1164,6 +1217,9 @@ void activate_playlist_manager ()
 
 void update_toolbar_icons ()
 {
+    if (menu_button)
+        set_menu_button_icon ((GtkToolButton *) menu_button);
+
     set_button_icon ((GtkToolButton *) search_button, "edit-find");
     set_button_icon ((GtkToolButton *) button_open, "document-open");
     set_button_icon ((GtkToolButton *) button_add, "list-add");
@@ -1175,4 +1231,9 @@ void update_toolbar_icons ()
     set_button_icon ((GtkToolButton *) button_record, "media-record");
     set_button_icon ((GtkToolButton *) button_repeat, "media-playlist-repeat");
     set_button_icon ((GtkToolButton *) button_shuffle, "media-playlist-shuffle");
+
+#ifdef USE_GTK3
+    bool use_symbolic = aud_get_bool ("gtkui", "symbolic_icons");
+    g_object_set ((GObject *) volume, "use-symbolic", use_symbolic, nullptr);
+#endif
 }
