@@ -32,6 +32,7 @@
 #include "playlist_model.h"
 
 #include "../ui-common/menu-ops.h"
+#include "../ui-common/qt-compat.h"
 
 PlaylistWidget::PlaylistWidget(QWidget * parent, Playlist playlist)
     : audqt::TreeView(parent), m_playlist(playlist),
@@ -49,8 +50,6 @@ PlaylistWidget::PlaylistWidget(QWidget * parent, Playlist playlist)
 
     auto header = new PlaylistHeader(this);
     setHeader(header);
-    /* this has to come after setHeader() to take effect */
-    header->setSectionsClickable(true);
 
     setAllColumnsShowFocus(true);
     setAlternatingRowColors(true);
@@ -228,10 +227,10 @@ void PlaylistWidget::dropEvent(QDropEvent * event)
     switch (dropIndicatorPosition())
     {
     case AboveItem:
-        to = indexToRow(indexAt(event->pos()));
+        to = indexToRow(indexAt(QtCompat::pos(event)));
         break;
     case BelowItem:
-        to = indexToRow(indexAt(event->pos())) + 1;
+        to = indexToRow(indexAt(QtCompat::pos(event))) + 1;
         break;
     case OnViewport:
         to = m_playlist.n_entries();
@@ -540,5 +539,8 @@ void PlaylistWidget::hidePopup()
 
 void PlaylistWidget::updateSettings()
 {
+    header()->setSectionsClickable(
+        aud_get_bool("qtui", "playlist_headers_sortable"));
+
     setHeaderHidden(!aud_get_bool("qtui", "playlist_headers"));
 }
